@@ -4,41 +4,46 @@ __all__ = [
     "Unsupported",
     "ValidationError",
     "alias",
-    "deserialization",
+    "dependent_required",
+    "deserialization_method",
     "deserialize",
     "deserializer",
     "properties",
-    "reset_cache",
     "schema",
     "schema_ref",
+    "serialization_method",
     "serialize",
     "serialized",
     "serializer",
+    "settings",
+    "type_name",
     "validator",
 ]
 
 
 from . import (  # noqa: F401
+    cache,
     conversions,
     dataclasses,
     fields,
     json_schema,
     metadata,
-    settings,
+    objects,
     skip,
     tagged_unions,
     validation,
 )
 from .aliases import alias
-from .cache import reset_cache
 from .conversions import deserializer, serializer
-from .deserialization import deserialize
-from .json_schema.refs import schema_ref
-from .json_schema.schema import schema
+from .dependencies import dependent_required
+from .deserialization import deserialization_method, deserialize
 from .metadata import properties
-from .serialization import serialize
+from .schemas import schema
+from .serialization import serialization_method, serialize
 from .serialization.serialized_methods import serialized
-from .utils import Undefined, UndefinedType
+from .settings import settings
+from .type_names import schema_ref, type_name
+from .types import Undefined, UndefinedType
 from .validation import ValidationError, validator
 from .visitor import Unsupported
 
@@ -68,3 +73,4 @@ def register_default_conversions():
 
 
 register_default_conversions()
+del register_default_conversions
