@@ -1,5 +1,6 @@
+from dataclasses import Field, MISSING, field, make_dataclass
 from functools import wraps
-from inspect import Parameter, iscoroutinefunction, signature
+from inspect import Parameter, signature
 from typing import (
     Awaitable,
     Callable,
@@ -13,22 +14,19 @@ from typing import (
     TypeVar,
 )
 
-from dataclasses import Field, MISSING, field, make_dataclass
 from graphql.pyutils import camel_to_snake
 
 from apischema.aliases import alias
-from apischema.json_schema.refs import schema_ref
-from apischema.utils import Undefined
 from apischema.graphql.schema import Mutation as Mutation_
-from apischema.graphql.resolvers import awaitable_origin
-from apischema.json_schema.schema import Schema
+from apischema.schemas import Schema
 from apischema.serialization.serialized_methods import ErrorHandler
-from apischema.types import AnyType
+from apischema.type_names import type_name
+from apischema.types import AnyType, Undefined
 from apischema.typing import get_type_hints
-from apischema.utils import get_origin_or_type, is_union_of
+from apischema.utils import is_async, is_union_of, wrap_generic_init_subclass
 
 ClientMutationId = NewType("ClientMutationId", str)
-schema_ref(None)(ClientMutationId)
+type_name(None)(ClientMutationId)
 CLIENT_MUTATION_ID = "client_mutation_id"
 M = TypeVar("M", bound="Mutation")
 
@@ -42,6 +40,7 @@ class Mutation:
     # Mutate is not defined to prevent Mypy warning about signature of superclass
     mutate: Callable
 
+    @wrap_generic_init_subclass
     def __init_subclass__(cls, **kwargs):
         super().__init_subclass__(**kwargs)
         if not hasattr(cls, "mutate"):
@@ -49,12 +48,9 @@ class Mutation:
         if not isinstance(cls.__dict__["mutate"], (classmethod, staticmethod)):
             raise TypeError(f"{cls.__name__}.mutate must be a classmethod/staticmethod")
         mutate = getattr(cls, "mutate")
-        schema_ref(f"{cls.__name__}Payload")(cls)
+        type_name(f"{cls.__name__}Payload")(cls)
         types = get_type_hints(mutate, localns={cls.__name__: cls}, include_extras=True)
-        async_mutate = (
-            iscoroutinefunction(mutate)
-            or get_origin_or_type(types.get("return")) == awaitable_origin
-        )
+        async_mutate = is_async(mutate, types)
         fields: List[Tuple[str, AnyType, Field]] = []
         cmi_param = None
         for param_name, param in signature(mutate).parameters.items():
