@@ -1,24 +1,25 @@
 import re
+import warnings
 from dataclasses import dataclass
 from typing import Callable, Optional, Pattern, TYPE_CHECKING, Tuple, Union
 
 from apischema.metadata.keys import (
-    CONVERSIONS_METADATA,
-    DEFAULT_AS_SET,
-    DEFAULT_FALLBACK_METADATA,
+    CONVERSION_METADATA,
+    DEFAULT_AS_SET_METADATA,
+    FALL_BACK_ON_DEFAULT_METADATA,
+    FLATTENED_METADATA,
     INIT_VAR_METADATA,
-    MERGED_METADATA,
     POST_INIT_METADATA,
     PROPERTIES_METADATA,
     REQUIRED_METADATA,
     SKIP_METADATA,
     VALIDATORS_METADATA,
 )
-from apischema.types import AnyType, MetadataImplem, Metadata, MetadataMixin
+from apischema.types import AnyType, Metadata, MetadataImplem, MetadataMixin
 
 if TYPE_CHECKING:
-    from apischema.conversions.conversions import Conversions
-    from apischema.validation.validator import Validator
+    from apischema.conversions.conversions import AnyConversion
+    from apischema.validation.validators import Validator
 
 
 def simple_metadata(key: str) -> Metadata:
@@ -27,34 +28,25 @@ def simple_metadata(key: str) -> Metadata:
 
 @dataclass(frozen=True)
 class ConversionMetadata(MetadataMixin):
-    key = CONVERSIONS_METADATA
-    deserialization: Optional["Conversions"] = None
-    serialization: Optional["Conversions"] = None
+    key = CONVERSION_METADATA
+    deserialization: Optional["AnyConversion"] = None
+    serialization: Optional["AnyConversion"] = None
 
 
-if False:  # For Pycharm
+conversion = ConversionMetadata
 
-    def conversion(
-        deserialization: "Conversions" = None,
-        serialization: "Conversions" = None,
-    ) -> ConversionMetadata:
-        ...
+default_as_set = simple_metadata(DEFAULT_AS_SET_METADATA)
 
+fall_back_on_default = simple_metadata(FALL_BACK_ON_DEFAULT_METADATA)
 
-else:
-    conversion = ConversionMetadata
-
-
-default_as_set = simple_metadata(DEFAULT_AS_SET)
-
-default_fallback = simple_metadata(DEFAULT_FALLBACK_METADATA)
+flattened = simple_metadata(FLATTENED_METADATA)
 
 
 def init_var(tp: AnyType) -> Metadata:
     return MetadataImplem({INIT_VAR_METADATA: tp})
 
 
-merged = simple_metadata(MERGED_METADATA)
+merged = flattened
 
 post_init = simple_metadata(POST_INIT_METADATA)
 
@@ -73,7 +65,6 @@ class PropertiesMetadata(dict, Metadata):  # type: ignore
 
 properties = PropertiesMetadata()
 
-
 required = simple_metadata(REQUIRED_METADATA)
 
 skip = simple_metadata(SKIP_METADATA)
@@ -86,6 +77,14 @@ class ValidatorsMetadata(MetadataMixin):
 
 
 def validators(*validator: Callable) -> ValidatorsMetadata:
-    from apischema.validation.validator import Validator
+    from apischema.validation.validators import Validator
 
     return ValidatorsMetadata(tuple(map(Validator, validator)))
+
+
+def __getattr__(name):
+    if name == "merged":
+        warnings.warn(
+            "metadata.merged is deprecated, use metadata.flattened instead",
+            DeprecationWarning,
+        )
