@@ -16,27 +16,28 @@ from typing import (
     overload,
 )
 
-from apischema.conversions.conversions import Conversions
+from apischema.conversions.conversions import AnyConversion
 from apischema.conversions.dataclass_models import get_model_origin, has_model_origin
-from apischema.json_schema.schema import Schema
-from apischema.types import AnyType
-from apischema.typing import generic_mro, get_args, get_type_hints
+from apischema.schemas import Schema
+from apischema.types import AnyType, Undefined, UndefinedType
+from apischema.typing import generic_mro, get_args, get_origin, get_type_hints
 from apischema.utils import (
-    Undefined,
-    UndefinedType,
+    deprecate_kwargs,
     get_args2,
-    get_origin2,
     get_origin_or_type,
+    get_origin_or_type2,
     get_parameters,
     method_registerer,
     substitute_type_vars,
+    subtyping_substitution,
+    type_dict_wrapper,
 )
 
 
 @dataclass(frozen=True)
-class Serialized:
+class SerializedMethod:
     func: Callable
-    conversions: Optional[Conversions]
+    conversion: Optional[AnyConversion]
     schema: Optional[Schema]
     error_handler: Optional[Callable]
 
@@ -63,8 +64,9 @@ class Serialized:
                 raise TypeError("Function must be typed")
         types["return"] = self.return_type(types["return"])
         if get_args2(owner):
-            substitution = dict(
-                zip(get_parameters(get_origin2(owner)), get_args2(owner))
+            first_param = next(iter(signature(self.func).parameters))
+            substitution, _ = subtyping_substitution(
+                types.get(first_param, get_origin_or_type2(owner)), owner
             )
             types = {
                 name: substitute_type_vars(tp, substitution)
@@ -73,9 +75,11 @@ class Serialized:
         return types
 
 
-_serialized_methods: Dict[Type, Dict[str, Serialized]] = defaultdict(dict)
+_serialized_methods: Dict[Type, Dict[str, SerializedMethod]] = type_dict_wrapper(
+    defaultdict(dict)
+)
 
-S = TypeVar("S", bound=Serialized)
+S = TypeVar("S", bound=SerializedMethod)
 
 
 def _get_methods(
@@ -87,8 +91,8 @@ def _get_methods(
             result[name] = (method, method.types(base))
     if has_model_origin(tp):
         origin = get_model_origin(tp)
-        if get_args2(tp):
-            substitution = dict(zip(get_parameters(tp), get_args(tp)))
+        if get_args(tp):
+            substitution = dict(zip(get_parameters(get_origin(tp)), get_args(tp)))
             origin = substitute_type_vars(origin, substitution)
         result.update(_get_methods(origin, all_methods))
     return result
@@ -96,7 +100,7 @@ def _get_methods(
 
 def get_serialized_methods(
     tp: AnyType,
-) -> Mapping[str, Tuple[Serialized, Mapping[str, AnyType]]]:
+) -> Mapping[str, Tuple[SerializedMethod, Mapping[str, AnyType]]]:
     return _get_methods(tp, _serialized_methods)
 
 
@@ -119,7 +123,7 @@ def serialized(__method_or_property: MethodOrProp) -> MethodOrProp:
 def serialized(
     alias: str = None,
     *,
-    conversions: Conversions = None,
+    conversion: AnyConversion = None,
     schema: Schema = None,
     error_handler: ErrorHandler = Undefined,
     owner: Type = None,
@@ -127,16 +131,17 @@ def serialized(
     ...
 
 
+@deprecate_kwargs({"conversions": "conversion"})
 def serialized(
     __arg=None,
     *,
     alias: str = None,
-    conversions: Conversions = None,
+    conversion: AnyConversion = None,
     schema: Schema = None,
     error_handler: ErrorHandler = Undefined,
     owner: Type = None,
 ):
-    def register(func: Callable, owner: Optional[Type], alias2: str):
+    def register(func: Callable, owner: Type, alias2: str):
         alias2 = alias or alias2
         parameters = list(signature(func).parameters.values())
         for param in parameters[1:]:
@@ -161,14 +166,7 @@ def serialized(
                     return error_handler(error, self, alias2)
 
         assert not isinstance(error_handler2, UndefinedType)
-        serialized = Serialized(func, conversions, schema, error_handler2)
-        if owner is None:
-            try:
-                owner = get_origin_or_type(get_type_hints(func)[parameters[0].name])
-            except KeyError:
-                raise TypeError(
-                    "First parameter of serialized method must be typed"
-                ) from None
+        serialized = SerializedMethod(func, conversion, schema, error_handler2)
         _serialized_methods[owner][alias2] = serialized
 
     if isinstance(__arg, str):
