@@ -16,21 +16,21 @@ from typing import (
 
 from apischema.aliases import alias as alias_metadata
 from apischema.conversions.conversions import ConvOrFunc
-from apischema.json_schema.schema import Schema, schema
 from apischema.metadata import conversion
 from apischema.metadata.keys import (
-    DEFAULT_AS_SET,
-    DEFAULT_FALLBACK_METADATA,
+    DEFAULT_AS_SET_METADATA,
+    FALL_BACK_ON_DEFAULT_METADATA,
+    FLATTENED_METADATA,
     INIT_VAR_METADATA,
-    MERGED_METADATA,
     POST_INIT_METADATA,
     PROPERTIES_METADATA,
     REQUIRED_METADATA,
     SKIP_METADATA,
 )
-from apischema.types import Metadata, MetadataImplem
+from apischema.schemas import Schema, schema
+from apischema.types import Metadata, MetadataImplem, Undefined, UndefinedType
 from apischema.typing import get_type_hints
-from apischema.utils import PREFIX, Undefined, UndefinedType, get_args2, get_origin2
+from apischema.utils import PREFIX, get_args2, get_origin2, wrap_generic_init_subclass
 
 TAGS_ATTR = f"{PREFIX}tags"
 
@@ -51,10 +51,10 @@ class Tag(str, Generic[T, V]):
 
 
 INVALID_METADATA = {
-    DEFAULT_AS_SET,
-    DEFAULT_FALLBACK_METADATA,
+    DEFAULT_AS_SET_METADATA,
+    FALL_BACK_ON_DEFAULT_METADATA,
     INIT_VAR_METADATA,
-    MERGED_METADATA,
+    FLATTENED_METADATA,
     POST_INIT_METADATA,
     PROPERTIES_METADATA,
     REQUIRED_METADATA,
@@ -77,7 +77,10 @@ class Tagged(Generic[V]):
         deserialization: Optional[ConvOrFunc],
         serialization: Optional[ConvOrFunc],
     ):
-        # TODO Remove deprecated part
+        if self.metadata is None or isinstance(self.metadata, str):
+            raise TypeError(
+                "Tagged alias parameter is deprecated, use metadata instead"
+            )
         if any(m is not None for m in (alias, schema, deserialization, serialization)):
             metadata = self.metadata
             warnings.warn(
@@ -123,6 +126,7 @@ class TaggedUnion:
         tag, value = get_tagged(self)
         return f"{type(self).__name__}({tag}={value!r})"
 
+    @wrap_generic_init_subclass
     def __init_subclass__(cls, **kwargs):
         tags = set(getattr(cls, TAGS_ATTR, ()))
         types = get_type_hints(cls, include_extras=True)
